OC.L10N.register(
    "dav",
    {
    "Calendar" : "Takvim",
    "Tasks" : "Görevler",
    "Personal" : "Kişisel",
    "{actor} created calendar {calendar}" : "{actor}, {calendar} takvimini ekledi",
    "You created calendar {calendar}" : "{calendar} takvimini eklediniz",
    "{actor} deleted calendar {calendar}" : "{actor}, {calendar} takvimini sildi",
    "You deleted calendar {calendar}" : "{calendar} takvimini sildiniz",
    "{actor} updated calendar {calendar}" : "{actor}, {calendar} takvimini güncelledi",
    "You updated calendar {calendar}" : "{calendar} takvimini güncellediniz",
    "{actor} restored calendar {calendar}" : "{actor}, {calendar} takvimini geri yükledi",
    "You restored calendar {calendar}" : "{calendar} takvimini geri yüklediniz",
    "You shared calendar {calendar} as public link" : "{calendar} takvimini herkese açık bağlantı olarak paylaştınız",
    "You removed public link for calendar {calendar}" : "{calendar} takviminin herkese açık bağlantısını kaldırdınız",
    "{actor} shared calendar {calendar} with you" : "{actor}, {calendar} takvimini sizinle paylaştı",
    "You shared calendar {calendar} with {user}" : "{calendar} takvimini {user} kullanıcısı ile paylaştınız",
    "{actor} shared calendar {calendar} with {user}" : "{actor}, {calendar} takvimini {user} kullanıcısı ile paylaştı",
    "{actor} unshared calendar {calendar} from you" : "{actor}, {calendar} takviminin sizinle paylaşımını kaldırdı",
    "You unshared calendar {calendar} from {user}" : "{calendar} takviminin {user} kullanıcısı ile paylaşımını kaldırdınız",
    "{actor} unshared calendar {calendar} from {user}" : "{actor}, {calendar} takviminin {user} kullanıcısı ile paylaşımını kaldırdı",
    "{actor} unshared calendar {calendar} from themselves" : "{actor}, {calendar} takviminin kendisi ile paylaşımını kaldırdı",
    "You shared calendar {calendar} with group {group}" : "{calendar} takvimini {group} grubu ile paylaştınız",
    "{actor} shared calendar {calendar} with group {group}" : "{actor}, {calendar} takvimini {group} grubu ile paylaştı",
    "You unshared calendar {calendar} from group {group}" : "{calendar} takviminin {group} grubu ile paylaşımını kaldırdınız",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}, {calendar} takviminin {group} grubu ile paylaşımını kaldırdı",
    "Untitled event" : "Adlandırılmamış etkinlik",
    "{actor} created event {event} in calendar {calendar}" : "{actor}, {calendar} takvimine {event} etkinliğini ekledi",
    "You created event {event} in calendar {calendar}" : "{calendar} takvimine {event} etkinliğini eklediniz",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor}, {calendar} takviminden {event} etkinliğini sildi",
    "You deleted event {event} from calendar {calendar}" : "{calendar} takviminden {event} etkinliğini sildiniz",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}, {calendar} takvimindeki {event} etkinliğini güncelledi",
    "You updated event {event} in calendar {calendar}" : "{calendar} takvimindeki {event} etkinliğini güncellediniz",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor}, {event} etkinliğini {sourceCalendar} takviminden {targetCalendar} takvimine taşıdı",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{event} etkinliğini {sourceCalendar} takviminden {targetCalendar} takvimine taşıdınız",
    "{actor} restored event {event} of calendar {calendar}" : "{actor}, {calendar} takvimindeki {event} etkinliğini geri yükledi",
    "You restored event {event} of calendar {calendar}" : "{calendar} takvimindeki {event} etkinliğini geri yüklediniz",
    "Busy" : "Meşgul",
    "{actor} created to-do {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesine {todo} yapılacak işini ekledi",
    "You created to-do {todo} in list {calendar}" : "{calendar} takvimi listesine {todo} yapılacak işini eklediniz",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor}, {calendar} takvimi listesinden {todo} yapılacak işini sildi",
    "You deleted to-do {todo} from list {calendar}" : "{calendar} takvimi listesinden {todo} yapılacak işini sildiniz",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini güncelledi",
    "You updated to-do {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini güncellediniz",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini tamamladı",
    "You solved to-do {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini tamamladınız",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini yeniden başlattı",
    "You reopened to-do {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini yeniden başlattınız",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor}, {todo} yapılacak işini {sourceCalendar} listesinden {targetCalendar} listesine taşıdı",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{todo} yapılacak işini {sourceCalendar} listesinden {targetCalendar} listesine taşıdınız",
    "Calendar, contacts and tasks" : "Takvim, kişiler ve görevler",
    "A <strong>calendar</strong> was modified" : "Bir <strong>takvim</strong> düzenlendi",
    "A calendar <strong>event</strong> was modified" : "Bir takvim <strong>etkinliği</strong> düzenlendi",
    "A calendar <strong>to-do</strong> was modified" : "Bir takvim <strong>yapılacak işi</strong> düzenlendi",
    "Contact birthdays" : "Kişi doğum günleri",
    "Death of %s" : "%s ölümü",
    "Untitled calendar" : "Adlandırılmamış takvim",
    "Calendar:" : "Takvim:",
    "Date:" : "Tarih:",
    "Where:" : "Yer:",
    "Description:" : "Açıklama:",
    "_%n year_::_%n years_" : ["%n yıl","%n yıl"],
    "_%n month_::_%n months_" : ["%n ay","%n ay"],
    "_%n day_::_%n days_" : ["%n gün","%n gün"],
    "_%n hour_::_%n hours_" : ["%n saat","%n saat"],
    "_%n minute_::_%n minutes_" : ["%n dakika","%n dakika"],
    "%s (in %s)" : "%s (%s içinde)",
    "%s (%s ago)" : "%s (%s önce)",
    "Calendar: %s" : "Takvim: %s",
    "Date: %s" : "Tarih: %s",
    "Description: %s" : "Açıklama: %s",
    "Where: %s" : "Şurada: %s",
    "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
    "In a %1$s on %2$s for the entire day" : "Tüm gün boyunca %1$s içinde %2$s zamanında",
    "In a %1$s on %2$s between %3$s - %4$s" : "%1$s içinde %2$s zamanında %3$sile %4$s arasında",
    "In %1$s %2$s on %3$s for the entire day" : "Tüm gün boyunca %1$s %2$s içinde %3$s zamanında",
    "In %1$s %2$s on %3$s between %4$s - %5$s" : "%1$s %2$s içinde %3$s zamanında %4$s ile %5$s arasında",
    "Could not generate when statement" : "Zaman ifadesi oluşturulamadı",
    "Every Day for the entire day" : "Her gün tüm gün boyunca",
    "Every Day for the entire day until %1$s" : "%1$s zamanına kadar her gün tüm gün boyunca",
    "Every Day between %1$s - %2$s" : "Her gün %1$s ile %2$s arasında",
    "Every Day between %1$s - %2$s until %3$s" : "%3$s zamanına kadar %1$s ile %2$s arasında her gün",
    "Every %1$d Days for the entire day" : "Her %1$d günde tüm gün boyunca",
    "Every %1$d Days for the entire day until %2$s" : "%2$s zamanına kadar her %1$d günde tüm gün boyunca",
    "Every %1$d Days between %2$s - %3$s" : "Her %1$d günde %2$s ile %3$s arasında",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "%4$s zamanına kadar her %1$d günde %2$s ile %3$s",
    "Could not generate event recurrence statement" : "Etkinlik yinelenme ifadesi oluşturulamadı",
    "Every Week on %1$s for the entire day" : "Her hafta %1$s tüm gün boyunca",
    "Every Week on %1$s for the entire day until %2$s" : "Her hafta %1$s tüm gün boyunca %2$s zamanına kadar",
    "Every Week on %1$s between %2$s - %3$s" : "Her hafta %1$s %2$s ile %3$s arasında",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Her hafta %1$s %2$s ile %3$s arasında %4$s zamanına kadar",
    "Every %1$d Weeks on %2$s for the entire day" : "Her %1$d haftada bir %2$s tüm gün boyunca",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Her %1$d haftada bir %2$s tüm gün boyunca %3$s zamanına kadar",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Her %1$d haftada bir %2$s tüm gün boyunca %3$s ile %4$s arasında",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Her %1$d haftada bir %2$s %3$s ile %4$s arasında %5$s zamanına kadar",
    "Every Month on the %1$s for the entire day" : "Her ay %1$s tüm gün boyunca",
    "Every Month on the %1$s for the entire day until %2$s" : "Her ay %1$s tüm gün boyunca %2$s zamanına kadar",
    "Every Month on the %1$s between %2$s - %3$s" : "Her ay %1$s %2$s ile %3$s arasında",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Her ay %1$s %2$s ile %3$s arasında %4$s zamanına kadar",
    "Every %1$d Months on the %2$s for the entire day" : "Her %1$d ayda bir %2$s tüm gün boyunca",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Her %1$d ayda bir %2$s tüm gün boyunca %3$s zamanına kadar",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Her %1$d ayda bir %2$s tüm gün boyunca %3$s ile %4$s arasında",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Her %1$d ayda bir %2$s %3$s ile %4$s arasında %5$s zamanına kadar",
    "Every Year in %1$s on the %2$s for the entire day" : "Her yıl %1$s ayında %2$s tüm gün boyunca",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Her yıl %1$s ayında %2$s tüm gün boyunca %3$s zamanına kadar",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Her yıl %1$s ayında %2$s tüm gün boyunca %3$s ile %4$s arasında",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Her yıl %1$s ayında %2$s %3$s ile %4$s arasında %5$s zamanına kadar",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Her %1$d yılda bir %2$s ayında %3$s tüm gün boyunca",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Her %1$d yılda bir %2$s ayında %3$s tüm gün boyunca %4$s zamanına kadar",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Her %1$d yılda bir %2$s ayında %3$s tüm gün boyunca %4$s ile %5$s arasında",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Her %1$d yılda bir %2$s ayında %3$s %4$s ile %5$s arasında %6$s zamanına kadar",
    "On specific dates for the entire day until %1$s" : "Belirli tarihlerde tüm gün boyunca %1$s zamanına kadar",
    "On specific dates between %1$s - %2$s until %3$s" : "Belirli günlerde %1$s ile %2$s arasında %3$s zamanına kadar",
    "In a %1$s on %2$s" : "%1$s içinde %2$s",
    "In a %1$s on %2$s then on %3$s" : "%1$s içinde %2$s ve %3$s",
    "In a %1$s on %2$s then on %3$s and %4$s" : "%1$s içinde %2$s, %3$s ve %4$s",
    "In %1$s %2$s on %3$s" : "%1$s %2$s içinde %3$s",
    "In %1$s %2$s on %3$s then on %4$s" : "%1$s %2$s içinde %3$s ve %4$s",
    "In %1$s %2$s on %3$s then on %4$s and %5$s" : "%1$s %2$s içinde %3$s, %4$s ve %5$s",
    "Could not generate next recurrence statement" : "Sonraki yinelenme ifadesi oluşturulamadı",
    "Cancelled: %1$s" : "İptal edildi: %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" iptal edildi",
    "Re: %1$s" : "Ynt: %1$s",
    "%1$s has accepted your invitation" : "%1$s davetinizi kabul etti",
    "%1$s has tentatively accepted your invitation" : "%1$s davetinizi belirsiz olarak kabul etti",
    "%1$s has declined your invitation" : "%1$s davetinizi reddetti.",
    "%1$s has responded to your invitation" : "%1$s davetinizi yanıtladı",
    "Invitation updated: %1$s" : "Davet güncellendi: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s, \"%2$s\" etkinliğini güncelledi",
    "Invitation: %1$s" : "Davet: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s, size \"%2$s\" için davet gönderdi",
    "Organizer:" : "Düzenleyen:",
    "Attendees:" : "Katılımcılar:",
    "Title:" : "Başlık:",
    "When:" : "Zaman:",
    "Location:" : "Konum:",
    "Link:" : "Bağlantı:",
    "Occurring:" : "Başlangıç:",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "More options …" : "Diğer seçenekler …",
    "More options at %s" : "%s üzerindeki diğer seçenekler",
    "Monday" : "Pazartesi",
    "Tuesday" : "Salı",
    "Wednesday" : "Çarşamba",
    "Thursday" : "Perşembe",
    "Friday" : "Cuma",
    "Saturday" : "Cumartesi",
    "Sunday" : "Pazar",
    "January" : "Ocak",
    "February" : "Şubat",
    "March" : "Mart",
    "April" : "Nisan",
    "May" : "Mayıs",
    "June" : "Haziran",
    "July" : "Temmuz",
    "August" : "Ağustos",
    "September" : "Eylül",
    "October" : "Ekim",
    "November" : "Kasım",
    "December" : "Aralık",
    "First" : "İlk",
    "Second" : "İkinci",
    "Third" : "Üçüncü",
    "Fourth" : "Dördüncü",
    "Fifty" : "Beşinci",
    "Last" : "Son",
    "Second Last" : "İkinci son",
    "Third Last" : "Üçüncü son",
    "Fourth Last" : "Dördüncü son",
    "Fifty Last" : "Beşinci son",
    "Contacts" : "Kişiler",
    "{actor} created address book {addressbook}" : "{actor}, {addressbook} adres defterini ekledi",
    "You created address book {addressbook}" : "{addressbook} adres defterini eklediniz",
    "{actor} deleted address book {addressbook}" : "{actor}, {addressbook} adres defterini sildi",
    "You deleted address book {addressbook}" : "{addressbook} adres defterini sildiniz",
    "{actor} updated address book {addressbook}" : "{actor}, {addressbook} adres defterini güncelledi",
    "You updated address book {addressbook}" : "{addressbook} adres defterini güncellediniz",
    "{actor} shared address book {addressbook} with you" : "{actor}, {addressbook} adres defterini sizinle paylaştı",
    "You shared address book {addressbook} with {user}" : "{addressbook} adres defterini {user} kullanıcısı ile paylaştınız",
    "{actor} shared address book {addressbook} with {user}" : "{actor}, {addressbook} adres defterini {user} kullanıcısı ile paylaştı",
    "{actor} unshared address book {addressbook} from you" : "{actor}, {addressbook} adres defterinin sizinle paylaşımını kaldırdı",
    "You unshared address book {addressbook} from {user}" : "{addressbook} adres defterinin {user} kullanıcısı ile paylaşımını kaldırdınız",
    "{actor} unshared address book {addressbook} from {user}" : "{actor}, {addressbook} adres defterinin {user} kullanıcısı ile paylaşımını kaldırdı",
    "{actor} unshared address book {addressbook} from themselves" : "{actor}, {addressbook} adres defterinin kendileri ile paylaşımını kaldırdı",
    "You shared address book {addressbook} with group {group}" : "{addressbook} adres defterini {group} grubu ile paylaştınız",
    "{actor} shared address book {addressbook} with group {group}" : "{actor}, {addressbook} adres defterini {group} grubu ile paylaştı",
    "You unshared address book {addressbook} from group {group}" : "{addressbook} adres defterinin {group} grubu ile paylaşımını kaldırdınız",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor}, {addressbook} adres defterinin {group} grubu ile paylaşımını kaldırdı",
    "{actor} created contact {card} in address book {addressbook}" : "{actor}, {addressbook} adres defterine {card} kişi kartını ekledi",
    "You created contact {card} in address book {addressbook}" : "{addressbook} adres defterine {card} kişi kartını eklediniz",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor}, {addressbook} adres defterinden {card} kişi kartını sildi",
    "You deleted contact {card} from address book {addressbook}" : "{addressbook} adres defterinden {card} kişi kartını sildiniz",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor}, {addressbook} adres defterindeki {card} kişi kartını güncelledi",
    "You updated contact {card} in address book {addressbook}" : "{addressbook} adres defterindeki {card} kişi kartını güncellediniz",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Bir <strong>kişi</strong> ya da <strong>adres defteri</strong> değiştirildiğinde",
    "Accounts" : "Hesaplar",
    "System address book which holds all accounts" : "Tüm hesapların bulunduğu sistem adres defteri",
    "File is not updatable: %1$s" : "Dosya güncellenebilir değil: %1$s",
    "Failed to get storage for file" : "Dosyanın depolaması alınamadı",
    "Could not write to final file, canceled by hook" : "Sonuç dosyasına yazılamadı, bağlantı tarafından iptal edildi",
    "Could not write file contents" : "Dosya içerikleri yazılamadı",
    "_%n byte_::_%n bytes_" : ["%n bayt","%n bayt"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Dosya hedef konuma kopyalanırken sorun çıktı (Kopyalanan: %1$s, Beklenen dosya boyutu: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "%1$s dosya boyutu bekleniyordu, ancak %2$s okundu (Nextcloud istemcisinden) ve yazıldı (Nextcloud depolamasına). Gönderici tarafında bir ağ sorunu veya sunucu tarafında depolamaya yazma sorunu olabilir.",
    "Could not rename part file to final file, canceled by hook" : "Parça dosyası sonuç dosyası olarak yeniden adlandırılamadı, bağlantı tarafından iptal edildi",
    "Could not rename part file to final file" : "Parça dosyası sonuç dosyası olarak yeniden adlandırılamadı",
    "Failed to check file size: %1$s" : "Dosya boyutu denetlenemedi: %1$s",
    "Could not open file" : "Dosya açılamadı",
    "Encryption not ready: %1$s" : "Şifreleme hazır değil: %1$s",
    "Failed to open file: %1$s" : "Dosya açılamadı: %1$s",
    "Failed to unlink: %1$s" : "Bağlantı kaldırılamadı: %1$s",
    "Failed to write file contents: %1$s" : "Dosya içerikleri yazılamadı: %1$s",
    "File not found: %1$s" : "Dosya bulunamadı: %1$s",
    "Invalid target path" : "Hedef yol geçersiz",
    "System is in maintenance mode." : "Sistem bakım kipinde.",
    "Upgrade needed" : "Yükseltme gerekiyor",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS üzerinde CalDAV ve CardDAV kullanabilmek için %s HTTPS kullanacak şekilde yapılandırılmalıdır.",
    "Configures a CalDAV account" : "Bir CalDAV hesabı yapılandırır",
    "Configures a CardDAV account" : "Bir CardDAV hesabı yapılandırır",
    "Events" : "Etkinlikler",
    "Untitled task" : "Adlandırılmamış görev",
    "Completed on %s" : "%s tarihinde tamamlandı",
    "Due on %s by %s" : "%s tarihine kadar %s tarafından",
    "Due on %s" : "%s tarihine kadar",
    "DAV system address book" : "DAV sistem adres defteri",
    "No outstanding DAV system address book sync." : "Bekleyen bir DAV sistemi adres defteri eşitlemesi yok.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Kopyanızda 1000 üzerinde kullanıcı olduğundan ya da bir sorun çıktığından DAV sistemi adres defteri eşitlemesi henüz yapılmamış. Lütfen \"occ dav:sync-system-addressbook\" komutunu yürüterek el ile eşitleyin.",
    "WebDAV endpoint" : "WebDAV bağlantı noktası",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Site sunucunuzun WebDAV  üzerinden dosya eşitlemesi için doğru şekilde ayarlanıp ayarlanmadığı denetlenemedi. Lütfen el ile denetleyin.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Site sunucunuz dosya eşitlemesi için doğru şekilde ayarlanmamış. WebDAV arabirimi sorunlu görünüyor.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Site sunucunuz WebDAV  üzerinden dosya eşitlemesi için doğru şekilde ayarlanmış.",
    "Migrated calendar (%1$s)" : "Aktarılmış takvim (%1$s)",
    "Calendars including events, details and attendees" : "Etkinlikler, bilgiler ve katılımcılar ile takvimler",
    "Contacts and groups" : "Kişiler ve gruplar",
    "WebDAV" : "WebDAV",
    "First day" : "İlk gün",
    "Last day (inclusive)" : "Son gün (dahil)",
    "Out of office replacement (optional)" : "Ofis dışındayken yerine bakacak kişi (isteğe bağlı)",
    "Name of the replacement" : "Yerine bakacak kişi adı",
    "No results." : "Herhangi bir sonuç bulunamadı.",
    "Start typing." : "Yazmaya başlayın.",
    "Short absence status" : "Kısa işe gelmeme durumu",
    "Long absence Message" : "Uzun işe gelmeme iletisi",
    "Save" : "Kaydet",
    "Disable absence" : "İşe gelmemeyi kapat",
    "Absence saved" : "İşe gelmeme kaydedildi",
    "Failed to save your absence settings" : "İşe gelmeme ayarlarınız kaydedilemedi",
    "Absence cleared" : "İşe gelmeme temizlendi",
    "Failed to clear your absence settings" : "İşe gelmeme ayarlarınız temizlenemedi",
    "Time zone:" : "Saat dilimi:",
    "to" : "ile",
    "Delete slot" : "Aralığı sil",
    "No working hours set" : "Çalışma saatleri ayarlanmamış",
    "Add slot" : "Aralık ekle",
    "Weekdays" : "Hafta içi günleri",
    "Pick a start time for {dayName}" : "{dayName} için başlangıç zamanını seçin",
    "Pick a end time for {dayName}" : "{dayName} için bitiş zamanını seçin",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Tüm bildirimleri sessize almak için, uygunluk durumu dışında kullanıcı durumu otomatik olarak \"Rahatsız etmeyin\" olarak ayarlanır.",
    "Failed to load availability" : "Uygunluk yüklenemedi",
    "Saved availability" : "Uygunluk kaydedildi",
    "Failed to save availability" : "Uygunluk kaydedilemedi",
    "Availability" : "Uygunluk",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kişiler bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler.",
    "Absence" : "İşe gelmeme",
    "Configure your next absence period." : "Sonraki işe gelmeme aralığınızı yapılandırın.",
    "Calendar server" : "Takvim sunucusu",
    "Send invitations to attendees" : "Katılımcılara davet gönder",
    "Automatically generate a birthday calendar" : "Doğum günü takvimi otomatik oluşturulsun",
    "Birthday calendars will be generated by a background job." : "Bu seçenek kullanıma alındığında, doğum günü takvimi arka plan görevi olarak oluşturulur.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Kullanıma alındıktan hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
    "Send notifications for events" : "Etkinlik bildirimleri gönderilsin",
    "Notifications are sent via background jobs, so these must occur often enough." : "Bildirimler arka plan işlemleri tarafından gönderilir. Bu nedenle sıklık değeri uygun şekilde ayarlanmalıdır.",
    "Send reminder notifications to calendar sharees as well" : "Takvim paylaşımlarına da hatırlatma bildirimleri gönderilsin",
    "Reminders are always sent to organizers and attendees." : "Bu seçenek kullanıma alındığında, hatırlatıcılar her zaman düzenleyici ve katılımcılara gönderilir.",
    "Enable notifications for events via push" : "Anında etkinlik bildirimlerini aç",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ayrıca {calendarappstoreopen}Takvim Uygulamasını{linkclose} kurun ya da {calendardocopen}bilgisayarınızı ya da taşınabilir aygıtınızı eşitlemek üzere bağlayın  ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Lütfen {emailopen}e-posta sunucusunu{linkclose} doğru ayarladığınızdan emin olun.",
    "There was an error updating your attendance status." : "Katılım durumunuz güncellenirken bir sorun çıktı.",
    "Please contact the organizer directly." : "Lütfen düzenleyici ile doğrudan görüşün.",
    "Are you accepting the invitation?" : "Daveti kabul ediyor musunuz?",
    "Tentative" : "Kesin değil",
    "Your attendance was updated successfully." : "Katılımınız güncellendi.",
    "To-dos" : "Yapılacak işler",
    "Time:" : "Zaman:",
    "Invalid chunk name" : "Parça adı geçersiz",
    "Could not rename part file assembled from chunks" : "Parçalardan oluşturulan parça dosyası yeniden adlandırılamadı ",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kullanıcılar bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler."
},
"nplurals=2; plural=(n > 1);");
